Processor.App.processor\_utils.PipeMetadata.\_\_init\_\_
========================================================

.. currentmodule:: Processor.App.processor_utils

.. automethod:: PipeMetadata.__init__